@@ -18,9 +18,13 @@ def argparse():
         action="store", dest="table", type="string", default="", metavar='file',
         help="Path to the excel file (.xlsx) or table (.txt).")
 
+    jobsetup_opts.add_option("--focus",
+        action="store", dest="focus", type="string", default="", metavar='uniprot-id',
+        help="Uniprot ID to focus on. This means that it will the first chain in any predictions that contain it.")
+
     jobsetup_opts.add_option("--fragment",
         action="store", dest="fraglen", type="int", default=500, metavar='fragment-length',
-        help="Approximate fragment length. Default is 500.")
+        help="Approximate fragment length. Default is 500. For shorter fragments, try 250.")
 
     jobsetup_opts.add_option("--overlap",
         action="store", dest="overlap", type="int", default=50, metavar='overlap-length',
@@ -28,7 +32,15 @@ def argparse():
 
     jobsetup_opts.add_option("--dimerize",
         action="store", dest="dimerize", type="string", default="", metavar='dimerize-id',
-        help="Uniprot ID to dimerize.")
+        help="Uniprot ID to dimerize. Alternatively, provide a text file (.txt) with a single column list of uniprot IDs to dimerize.")
+
+    jobsetup_opts.add_option("--dimerize_all",
+        action="store_true", dest="dimerize_all", default=False,
+        help="Dimerize all proteins.")
+
+    jobsetup_opts.add_option("--dimerize_all_except",
+        action="store", dest="dimerize_except", type="string", default="", metavar='ids-not-to-dimerize',
+        help="Provide a text file (.txt) with a single column list of uniprot IDs to NOT dimerize. Everything else will be dimerized.")
 
     jobsetup_opts.add_option("--consider",
         action="store", dest="consider", type="string", default="", metavar='sequence-to-consider',
@@ -75,10 +87,14 @@ def argparse():
     analyze_opts.add_option("--write_table",
         action="store_true", dest="writetable", default=False,
         help="Write the full results as a table ranked by iptm.")
+
+    jobsetup_opts.add_option("--rankby",
+        action="store", dest="rankby", type="string", default="iptm", metavar='ptm-or-iptm',
+        help="Score by which models are ranked (ptm or iptm). Default is iptm. This is used for both choosing the best model in a prediction and then ranking the best models in the summaries.")
     
     analyze_opts.add_option("--overwrite",
         action="store_true", dest="overwrite", default=False,
-        help="Overwrite snapshot pngs if they already exist.")
+        help="Overwrite snapshot pngs if they already exist. Default is False.")
 
     parser.add_option_group(analyze_opts)
 
