@@ -29,9 +29,12 @@ def decide():
     params = argparser.argparse()
 
     table = params['table']
+    focus = params['focus']
     fraglen = params['fraglen']
     overlap = params['overlap']
     dimerize = params['dimerize']
+    dimerize_all = params['dimerize_all']
+    dimerize_except = params['dimerize_except']
     consider = params['consider']
     dontwrite = params['dontwrite']
     alphafold_exec = params['alphafold_exec']
@@ -42,6 +45,7 @@ def decide():
     threshold = params['threshold']
     overwrite = params['overwrite']
     writetable = params['writetable']
+    rankby = params['rankby']
 
     ##################################
     #Parse input
@@ -61,7 +65,7 @@ def decide():
 
     if writetable:
         print("\n>> Parsing results...")
-        df = analyze.getscores()
+        df = analyze.getscores(rankby)
         analyze.write_top(df, 0)
         sys.exit()
 
@@ -69,15 +73,15 @@ def decide():
 
     if threshold != -1:
         print("\n>> Parsing results...")
-        df = analyze.getscores()
+        df = analyze.getscores(rankby)
         if df.empty:
             sys.exit("\n>> Error: no results could be found.\n")
-        elif df[df['iptm']>threshold].empty:
-            sys.exit("\n>> Error: no results could be found with an iptm above " + str(threshold) + ".\n")
-        analyze.summarize_pae_pdf(df, threshold)
-        analyze.write_top(df, threshold)
-        analyze.write_modelpngs(df, threshold, overwrite=overwrite)
-        analyze.summarize_paeandmodel_pdf(df, threshold)
+        elif df[df[rankby]>threshold].empty:
+            sys.exit("\n>> Error: no results could be found with "+rankby+" above " + str(threshold) + ".\n")
+        analyze.summarize_pae_pdf(df, threshold, rankby)
+        analyze.write_top(df, threshold, rankby)
+        analyze.write_modelpngs(df, threshold, rankby, overwrite=overwrite)
+        analyze.summarize_paeandmodel_pdf(df, threshold, rankby)
         sys.exit()
 
     ##################################
@@ -100,9 +104,9 @@ def decide():
         else:
             sys.exit("\n>> Error: did not recognize filetype.\n")
 
-        Ainteractors, Binteractors = jobsetup.getinteractors(table, filetype, columnA, columnB)
+        Ainteractors, Binteractors = jobsetup.getinteractors(table, filetype, columnA, columnB, focus)
 
-        jobsetup.getfastas_writecommands(Ainteractors, Binteractors, consideruniprot, considerstart, considerend, split=True,fraglen=fraglen,overlap=overlap,dimerize=dimerize,write=towrite,alphafold_exec=alphafold_exec)
+        jobsetup.getfastas_writecommands(Ainteractors, Binteractors, consideruniprot, considerstart, considerend, split=True,fraglen=fraglen,overlap=overlap,dimerize=dimerize,dimerize_all=dimerize_all,dimerize_except=dimerize_except,write=towrite,alphafold_exec=alphafold_exec)
 
     ##################################
 
