@@ -10,9 +10,9 @@ def getuni(ACCESSION):
     NAME = ENTRY['uniProtkbId']
     return(NAME, SEQ)
 
-def getinteractors(file,filetype, columnA, columnB):
+def getinteractors(file,filetype, columnA, columnB, focus):
     
-    print(">> Reading table...\n")
+    print("\n>> Reading table...\n")
     if filetype == "table":
         table = pd.read_table(file, usecols=[columnA, columnB])
     elif filetype == "excel":
@@ -20,15 +20,47 @@ def getinteractors(file,filetype, columnA, columnB):
     
     Ainteractors = table[columnA].tolist()
     Binteractors = table[columnB].tolist()
-    
-    return(Ainteractors, Binteractors)
 
-def getfastas_writecommands(Ainteractors, Binteractors, consideruniprot,considerstart,considerend, split=True,fraglen=500,overlap=50,dimerize="",write=True,alphafold_exec="colabfold2"):
+    if focus != "":
+        if focus not in Ainteractors or focus not in Binteractors:
+            print("!! Warning: the uniprot ID " + focus + " was not found.\n")
+        Ainteractors_fixed = []
+        Binteractors_fixed = []
+        for A, B in zip(Ainteractors,Binteractors):
+            if B == focus:
+                Ainteractors_fixed.append(B)
+                Binteractors_fixed.append(A)
+            else:
+                Ainteractors_fixed.append(A)
+                Binteractors_fixed.append(B)
+        return(Ainteractors_fixed, Binteractors_fixed)
+    else:
+        return(Ainteractors, Binteractors)
+
+def getfastas_writecommands(Ainteractors, Binteractors, consideruniprot,considerstart,considerend, split=True,fraglen=500,overlap=50,dimerize="",dimerize_all=False,dimerize_except="",write=True,alphafold_exec="colabfold2"):
     
-    print("\nStarting...\n")
+    #print("\nStarting...\n")
     
-    if dimerize != "":
-        print(">> Dimerizing uniprot " + dimerize + "...\n")
+    dimerizelst = []
+    dontdimerizelst = []
+
+    if dimerize_all:
+        print(">> Dimerizing all proteins...\n")
+
+    elif dimerize_except:
+        print(">> Dimerizing all proteins except those in " + dimerize_except + "...\n")
+        with open(dimerize_except) as f:
+            dontdimerizelst=[line.strip() for line in f.readlines()]
+
+    elif dimerize != "":
+        if dimerize[-4:] == ".txt":
+            print(">> Dimerizing uniprot IDs in " + dimerize + "...\n")
+            with open(dimerize) as f:
+                dimerizelst=[line.strip() for line in f.readlines()]
+        else:
+            dimerizelst = [dimerize]
+            print(">> Dimerizing uniprot ID " + dimerize + "...\n")
+
 
     if consideruniprot != "":
         print(">> Only considering " + str(considerstart+1) + "-" + str(considerend+1) + " for uniprot ID"+consideruniprot+"...\n")
@@ -53,7 +85,7 @@ def getfastas_writecommands(Ainteractors, Binteractors, consideruniprot,consider
 
     for fname in os.listdir('fastas'):
         if fname.endswith('.fasta'):
-            print(">> Warning: it looks like fasta files already exist in the fastas folder.\n")
+            print("!! Warning: it looks like fasta files already exist in the fastas folder.\n")
             break
 
     colabfoldcommand = []
@@ -61,6 +93,10 @@ def getfastas_writecommands(Ainteractors, Binteractors, consideruniprot,consider
     Anamefail = []
     Bnamefail = []
 
+    if len(dontdimerizelst) != 0:
+        alluniprots = list(set(list(Ainteractors+Binteractors)))
+        dimerizelst = [i for i in alluniprots if i not in dontdimerizelst]
+
     print(">> Getting sequences...\n")
 
     for A, B in zip(Ainteractors, Binteractors):
@@ -92,15 +128,6 @@ def getfastas_writecommands(Ainteractors, Binteractors, consideruniprot,consider
                     sys.exit(">> Error: last amino acid to consider is outside the protein length. Maximum is " + str(len(Bseq)+1) + "\n")
                 Bseq = Bseq[considerstart:considerend]
                 addmeB = considerstart
-
-        todimer = ""
-        if dimerize != "":
-            if dimerize == A:
-                todimer = "A"
-            elif dimerize == B:
-                todimer = "B"
-            with open("dimerized-"+A+"-"+Aname, 'w') as f:
-                f.write("")
         
         if split:
             #print(Aname)
@@ -128,12 +155,12 @@ def getfastas_writecommands(Ainteractors, Binteractors, consideruniprot,consider
                         
                         f.write(">"+An+"\n"+As+"\n")
                         
-                        if todimer == "A":
+                        if A in dimerizelst or dimerize_all:
                             f.write(">"+An+"\n"+As+"\n")
                             
                         f.write(">"+Bn+"\n"+Bs+"\n")
                         
-                        if todimer == "B":
+                        if B in dimerizelst or dimerize_all:
                             f.write(">"+Bn+"\n"+Bs+"\n")
 
                 colabfoldcommand.append(alphafold_exec + " " + fastaname_minimal + " --output=results/" + An + "-" + Bn)
